@@ -95,7 +95,6 @@ typedef enum
   STATE_ALIAS,           /* 30 */
   STATE_TYPE,
   STATE_ATTRIBUTE,
-  STATE_DOC,
   STATE_PASSTHROUGH
 } ParseState;
 
@@ -342,6 +341,9 @@ state_switch (ParseContext *ctx, ParseState newstate)
   g_assert (ctx->state != newstate);
   ctx->prev_state = ctx->state;
   ctx->state = newstate;
+
+  if (ctx->state == STATE_PASSTHROUGH)
+    ctx->unknown_depth = 1;
 }
 
 static GIrNode *
@@ -725,10 +727,7 @@ introspectable_prelude (GMarkupParseContext *context,
   if (introspectable)
     state_switch (ctx, new_state);
   else
-    {
-      state_switch (ctx, STATE_PASSTHROUGH);
-      ctx->unknown_depth = 1;
-    }
+    state_switch (ctx, STATE_PASSTHROUGH);
 
   return introspectable;
 }
@@ -2116,22 +2115,6 @@ end_type (ParseContext *ctx)
     }
 }
 
-static gboolean
-start_doc (GMarkupParseContext *context,
-	   const gchar         *element_name,
-	   const gchar        **attribute_names,
-	   const gchar        **attribute_values,
-	   ParseContext       *ctx,
-	   GError             **error)
-{
-  if (strcmp (element_name, "doc") != 0)
-    return FALSE;
-
-  state_switch (ctx, STATE_DOC);
-
-  return TRUE;
-}
-
 static gboolean
 start_attribute (GMarkupParseContext *context,
                  const gchar         *element_name,
@@ -2765,9 +2748,11 @@ start_element_handler (GMarkupParseContext *context,
 			       attribute_names, attribute_values,
 			       ctx, error))
 	goto out;
-      else if (start_doc (context, element_name, attribute_names,
-			  attribute_values, ctx, error))
-	goto out;
+      if (strcmp (element_name, "doc") == 0)
+        {
+          state_switch (ctx, STATE_PASSTHROUGH);
+          goto out;
+        }
       break;
 
     case 'e':
@@ -2846,6 +2831,11 @@ start_element_handler (GMarkupParseContext *context,
 				 attribute_names, attribute_values,
 				 ctx, error))
 	goto out;
+      else if (strcmp (element_name, "instance-parameter") == 0)
+        {
+          state_switch (ctx, STATE_PASSTHROUGH);
+          goto out;
+        }
       else if (strcmp (element_name, "c:include") == 0)
 	{
 	  state_switch (ctx, STATE_C_INCLUDE);
@@ -3028,7 +3018,6 @@ start_element_handler (GMarkupParseContext *context,
 		    ctx->file_path, line_number, char_number, element_name,
 		    ctx->state);
       state_switch (ctx, STATE_PASSTHROUGH);
-      ctx->unknown_depth = 1;
     }
 
  out:
@@ -3413,13 +3402,6 @@ end_element_handler (GMarkupParseContext *context,
         }
       break;
 
-    case STATE_DOC:
-      if (strcmp ("doc", element_name) == 0)
-        {
-          state_switch (ctx, ctx->prev_state);
-        }
-      break;
-
     case STATE_PASSTHROUGH:
       ctx->unknown_depth -= 1;
       g_assert (ctx->unknown_depth >= 0);
