@@ -1,4 +1,5 @@
-/* GObject introspection: struct definitions for the binary
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
+ * GObject introspection: struct definitions for the binary
  * typelib format, validation
  *
  * Copyright (C) 2005 Matthias Clasen
@@ -281,7 +282,7 @@ typedef struct {
   guint32 sections;
 
   /* <private> */
-  guint16 padding[5];
+  guint16 padding[6];
 } Header;
 
 typedef enum {
@@ -433,6 +434,10 @@ typedef struct {
   gint8        closure;
   gint8        destroy;
 
+  /* <private> */
+  guint16      padding;
+  /* <public> */
+
   SimpleTypeBlob arg_type;
 } ArgBlob;
 
@@ -925,7 +930,8 @@ typedef struct {
   guint16 must_be_implemented     : 1;
   guint16 must_not_be_implemented : 1;
   guint16 class_closure           : 1;
-  guint16 reserved                :12;
+  guint16 throws                  : 1;
+  guint16 reserved                :11;
   guint16 signal;
 
   guint16 struct_offset;
@@ -1049,6 +1055,8 @@ typedef struct {
   guint16 n_vfuncs;
   guint16 n_constants;
 
+  guint16 padding;
+
   guint32 reserved2;
   guint32 reserved3;
 
@@ -1175,7 +1183,7 @@ void _gi_typelib_hash_builder_pack (GITypelibHashBuilder *builder, guint8* mem,
 
 void _gi_typelib_hash_builder_destroy (GITypelibHashBuilder *builder);
 
-guint16 _gi_typelib_hash_search (guint8* memory, const char *str);
+guint16 _gi_typelib_hash_search (guint8* memory, const char *str, guint n_entries);
 
 
 G_END_DECLS
