@@ -372,6 +372,10 @@ class Namespace(object):
         self.type_names = {} # Maps from GTName -> node
         self.ctypes = {} # Maps from CType -> node
         self.symbols = {} # Maps from function symbols -> Function
+        self.includes = set() # Include
+        self.shared_libraries = [] # str
+        self.c_includes = [] # str
+        self.exported_packages = [] # str
 
     def type_from_name(self, name, ctype=None):
         """Backwards compatibility method for older .gir files, which
@@ -1020,6 +1024,8 @@ class Class(Node, Registered):
                 field.anonymous_node.walk(callback, chain)
         for sig in self.signals:
             sig.walk(callback, chain)
+        for prop in self.properties:
+            prop.walk(callback, chain)
 
 
 class Interface(Node, Registered):
