@@ -192,7 +192,7 @@ usage is void (*_gtk_reserved1)(void);"""
     def _get_annotation_name(self, node):
         if isinstance(node, (ast.Class, ast.Interface, ast.Record,
                              ast.Union, ast.Enum, ast.Bitfield,
-                             ast.Callback, ast.Alias)):
+                             ast.Callback, ast.Alias, ast.Constant)):
             if node.ctype is not None:
                 return node.ctype
             elif isinstance(node, ast.Registered) and node.gtype_name is not None:
@@ -306,7 +306,7 @@ usage is void (*_gtk_reserved1)(void);"""
             else:
                 text = type_str
             message.warn_node(parent, "%s: Unknown type: %r" %
-                              (text, result.ctype), positions=position)
+                              (text, type_str), positions=position)
         return result
 
     def _resolve_toplevel(self, type_str, type_node=None, node=None, parent=None):
@@ -479,8 +479,8 @@ usage is void (*_gtk_reserved1)(void);"""
         assert supercls
         if cls is supercls:
             return True
-        if cls.parent and cls.parent.target_giname != 'GObject.Object':
-            return self._is_gi_subclass(cls.parent, supercls_type)
+        if cls.parent_type and cls.parent_type.target_giname != 'GObject.Object':
+            return self._is_gi_subclass(cls.parent_type, supercls_type)
         return False
 
     def _get_transfer_default_return(self, parent, node):
@@ -815,9 +815,12 @@ usage is void (*_gtk_reserved1)(void);"""
         self._apply_annotations_return(signal, signal.retval, block)
 
     def _apply_annotations_constant(self, node):
-        block = self._blocks.get(node.ctype)
-        if not block:
+        block = self._get_block(node)
+        if block is None:
             return
+
+        self._apply_annotations_annotated(node, block)
+
         tag = block.get_tag(TAG_VALUE)
         if tag:
             node.value = tag.value
@@ -895,11 +898,11 @@ the ones that failed to resolve removed."""
                     continue
                 target = self._transformer.lookup_typenode(parent)
                 if target:
-                    node.parent = parent
+                    node.parent_type = parent
                     break
             else:
                 if isinstance(node, ast.Interface):
-                    node.parent = ast.Type(target_giname='GObject.Object')
+                    node.parent_type = ast.Type(target_giname='GObject.Object')
             for prop in node.properties:
                 self._transformer.resolve_type(prop.type)
             for sig in node.signals:
@@ -1194,8 +1197,8 @@ method or constructor of some type."""
             while parent and (not parent.gi_name == 'GObject.Object'):
                 if parent == target:
                     break
-                if parent.parent:
-                    parent = self._transformer.lookup_typenode(parent.parent)
+                if parent.parent_type:
+                    parent = self._transformer.lookup_typenode(parent.parent_type)
                 else:
                     parent = None
                 if parent is None:
