@@ -42,8 +42,23 @@ from giscanner.sourcescanner import SourceScanner
 from giscanner.transformer import Transformer
 from . import utils
 
+def process_cflags_begin(option, opt, value, parser):
+    cflags = getattr(parser.values, option.dest)
+    while len(parser.rargs) > 0 and parser.rargs[0] != '--cflags-end':
+        cflags.append(parser.rargs.pop(0))
+
+def process_cflags_end(option, opt, value, parser):
+    pass
+
 def get_preprocessor_option_group(parser):
     group = optparse.OptionGroup(parser, "Preprocessor options")
+    group.add_option("", "--cflags-begin",
+                     help="Start preprocessor/compiler flags",
+                     dest="cflags", default=[],
+                     action="callback", callback=process_cflags_begin)
+    group.add_option("", "--cflags-end",
+                     help="End preprocessor/compiler flags",
+                     action="callback", callback=process_cflags_end)
     group.add_option("-I", help="Pre-processor include file",
                      action="append", dest="cpp_includes",
                      default=[])
@@ -193,11 +208,7 @@ def passthrough_gir(path, f):
     parser = GIRParser()
     parser.parse(path)
 
-    writer = GIRWriter(parser.get_namespace(),
-                       parser.get_shared_libraries(),
-                       parser.get_includes(),
-                       parser.get_pkgconfig_packages(),
-                       parser.get_c_includes())
+    writer = GIRWriter(parser.get_namespace())
     f.write(writer.get_xml())
 
 def test_codegen(optstring):
@@ -357,7 +368,8 @@ def create_source_scanner(options, args):
     ss = SourceScanner()
     ss.set_cpp_options(options.cpp_includes,
                        options.cpp_defines,
-                       options.cpp_undefines)
+                       options.cpp_undefines,
+                       cflags=options.cflags)
     ss.parse_files(filenames)
     ss.parse_macros(filenames)
     return ss
@@ -451,6 +463,8 @@ def scanner_main(args):
     else:
         shlibs = []
 
+    transformer.namespace.shared_libraries = shlibs
+
     main = MainTransformer(transformer, blocks)
     main.transform()
 
@@ -473,8 +487,9 @@ def scanner_main(args):
     else:
         exported_packages = options.packages
 
-    writer = Writer(transformer.namespace, shlibs, transformer.get_includes(),
-                    exported_packages, options.c_includes)
+    transformer.namespace.c_includes = options.c_includes
+    transformer.namespace.exported_packages = exported_packages
+    writer = Writer(transformer.namespace)
     data = writer.get_xml()
 
     write_output(data, options)
