@@ -3,7 +3,7 @@
 
 char backslash_parsing_tester = '\\';
 
-G_DEFINE_TYPE (AnnotationObject, annotation_object, G_TYPE_OBJECT);
+G_DEFINE_TYPE (RegressAnnotationObject, regress_annotation_object, G_TYPE_OBJECT);
 
 enum {
   PROP_0,
@@ -20,13 +20,13 @@ enum {
   LAST_SIGNAL
 };
 
-static guint annotation_object_signals[LAST_SIGNAL] = { 0 };
+static guint regress_annotation_object_signals[LAST_SIGNAL] = { 0 };
 
 static void
-annotation_object_set_property (GObject         *object,
-                                guint            prop_id,
-                                const GValue    *value,
-                                GParamSpec      *pspec)
+regress_annotation_object_set_property (GObject         *object,
+                                        guint            prop_id,
+                                        const GValue    *value,
+                                        GParamSpec      *pspec)
 {
   switch (prop_id)
     {
@@ -43,10 +43,10 @@ annotation_object_set_property (GObject         *object,
 }
 
 static void
-annotation_object_get_property (GObject         *object,
-                                guint            prop_id,
-                                GValue          *value,
-                                GParamSpec      *pspec)
+regress_annotation_object_get_property (GObject         *object,
+                                        guint            prop_id,
+                                        GValue          *value,
+                                        GParamSpec      *pspec)
 {
   switch (prop_id)
     {
@@ -63,18 +63,18 @@ annotation_object_get_property (GObject         *object,
 }
 
 static void
-annotation_object_class_init (AnnotationObjectClass *klass)
+regress_annotation_object_class_init (RegressAnnotationObjectClass *klass)
 {
   GObjectClass *gobject_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
 
-  gobject_class->set_property = annotation_object_set_property;
-  gobject_class->get_property = annotation_object_get_property;
+  gobject_class->set_property = regress_annotation_object_set_property;
+  gobject_class->get_property = regress_annotation_object_get_property;
 
   /**
-   * AnnotationObject::string-signal:
-   * @annotation: the annotation object
+   * RegressAnnotationObject::string-signal:
+   * @regress_annotation: the regress_annotation object
    * @string: (type utf8): a string
    *
    * This is a signal which has a broken signal handler,
@@ -83,7 +83,7 @@ annotation_object_class_init (AnnotationObjectClass *klass)
    * Since: 1.0
    * Deprecated: 1.2: Use other-signal instead
    */
-  annotation_object_signals[STRING_SIGNAL] =
+  regress_annotation_object_signals[STRING_SIGNAL] =
     g_signal_new ("string-signal",
 		  G_OBJECT_CLASS_TYPE (gobject_class),
 		  G_SIGNAL_RUN_LAST,
@@ -93,14 +93,14 @@ annotation_object_class_init (AnnotationObjectClass *klass)
 		  G_TYPE_NONE, 1, G_TYPE_POINTER);
 
   /**
-   * AnnotationObject::list-signal:
-   * @annotation: the annotation object
+   * RegressAnnotationObject::list-signal:
+   * @regress_annotation: the regress_annotation object
    * @list: (type GLib.List) (element-type utf8) (transfer container): a list of strings
    *
    * This is a signal which takes a list of strings, but it's not
    * known by GObject as it's only marked as G_TYPE_POINTER
    */
-  annotation_object_signals[LIST_SIGNAL] =
+  regress_annotation_object_signals[LIST_SIGNAL] =
     g_signal_new ("list-signal",
 		  G_OBJECT_CLASS_TYPE (gobject_class),
 		  G_SIGNAL_RUN_LAST,
@@ -110,13 +110,13 @@ annotation_object_class_init (AnnotationObjectClass *klass)
 		  G_TYPE_NONE, 1, G_TYPE_POINTER);
 
   /**
-   * AnnotationObject::doc-empty-arg-parsing:
-   * @annotation: the annotation object
+   * RegressAnnotationObject::doc-empty-arg-parsing:
+   * @regress_annotation: the regress_annotation object
    * @arg1:
    *
    * This signal tests an empty document argument (@arg1)
    */
-  annotation_object_signals[DOC_EMPTY_ARG_PARSING] =
+  regress_annotation_object_signals[DOC_EMPTY_ARG_PARSING] =
     g_signal_new ("doc-empty-arg-parsing",
 		  G_OBJECT_CLASS_TYPE (gobject_class),
 		  G_SIGNAL_RUN_LAST,
@@ -126,16 +126,16 @@ annotation_object_class_init (AnnotationObjectClass *klass)
 		  G_TYPE_NONE, 1, G_TYPE_POINTER);
 
   /**
-   * AnnotationObject::attribute-signal:
-   * @annotation: the annotation object
-   * @arg1: (attribute some.annotation.foo1 val1): a value
-   * @arg2: (attribute some.annotation.foo2 val2): another value
+   * RegressAnnotationObject::attribute-signal:
+   * @regress_annotation: the regress_annotation object
+   * @arg1: (attribute some.regress_annotation.foo1 val1): a value
+   * @arg2: (attribute some.regress_annotation.foo2 val2): another value
    *
    * This signal tests a signal with attributes.
    *
-   * Returns: (attribute some.annotation.foo3 val3): the return value
+   * Returns: (attribute some.regress_annotation.foo3 val3): the return value
    */
-  annotation_object_signals[ATTRIBUTE_SIGNAL] =
+  regress_annotation_object_signals[ATTRIBUTE_SIGNAL] =
     g_signal_new ("attribute-signal",
 		  G_OBJECT_CLASS_TYPE (gobject_class),
 		  G_SIGNAL_RUN_LAST,
@@ -148,7 +148,7 @@ annotation_object_class_init (AnnotationObjectClass *klass)
                   G_TYPE_STRING);
 
   /**
-   * AnnotationObject:string-property:
+   * RegressAnnotationObject:string-property:
    *
    * This is a property which is a string
    *
@@ -163,9 +163,9 @@ annotation_object_class_init (AnnotationObjectClass *klass)
                                                         NULL,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
   /**
-   * AnnotationObject:function-property:
+   * RegressAnnotationObject:function-property:
    *
-   * Type: AnnotationCallback
+   * Type: RegressAnnotationCallback
    */
   g_object_class_install_property (gobject_class,
                                    PROP_FUNCTION_PROPERTY,
@@ -174,14 +174,14 @@ annotation_object_class_init (AnnotationObjectClass *klass)
                                                          "This property is a function pointer",
                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
-	  /**
-	   * AnnotationObject:tab-property:
-	   *
-	   * This is a property annotation intentionally indented with a mix
-	   * of tabs and strings to test the tab handling capabilities of the scanner.
-	   *
-	   * Since: 1.2
-	   */
+  /**
+   * RegressAnnotationObject:tab-property:
+   *
+   * This is a property regress_annotation intentionally indented with a mix
+   * of tabs and strings to test the tab handling capabilities of the scanner.
+   *
+   * Since: 1.2
+   */
   g_object_class_install_property (gobject_class,
                                    PROP_TAB_PROPERTY,
                                    g_param_spec_string ("tab-property",
@@ -192,25 +192,25 @@ annotation_object_class_init (AnnotationObjectClass *klass)
 }
 
 static void
-annotation_object_init (AnnotationObject *object)
+regress_annotation_object_init (RegressAnnotationObject *object)
 {
 
 }
 
 /**
- * annotation_object_method:
+ * regress_annotation_object_method:
  * @object: a #GObject
  *
  * Return value: an int
  **/
 gint
-annotation_object_method (AnnotationObject *object)
+regress_annotation_object_method (RegressAnnotationObject *object)
 {
   return 1;
 }
 
 /**
- * annotation_object_out:
+ * regress_annotation_object_out:
  * @object: a #GObject
  * @outarg: (out): This is an argument test
  *
@@ -219,14 +219,14 @@ annotation_object_method (AnnotationObject *object)
  * Return value: an int
  */
 gint
-annotation_object_out (AnnotationObject *object, int *outarg)
+regress_annotation_object_out (RegressAnnotationObject *object, int *outarg)
 {
   *outarg = 2;
   return 1;
 }
 
 /**
- * annotation_object_in:
+ * regress_annotation_object_in:
  * @object: a #GObject
  * @inarg: (in) (transfer none): This is an argument test
  *
@@ -235,14 +235,14 @@ annotation_object_out (AnnotationObject *object, int *outarg)
  * Return value: an int
  */
 gint
-annotation_object_in (AnnotationObject *object, int *inarg)
+regress_annotation_object_in (RegressAnnotationObject *object, int *inarg)
 {
   return *inarg;
 }
 
 
 /**
- * annotation_object_inout:
+ * regress_annotation_object_inout:
  * @object: a #GObject
  * @inoutarg: (inout): This is an argument test
  *
@@ -251,13 +251,13 @@ annotation_object_in (AnnotationObject *object, int *inarg)
  * Return value: an int
  */
 gint
-annotation_object_inout (AnnotationObject *object, int *inoutarg)
+regress_annotation_object_inout (RegressAnnotationObject *object, int *inoutarg)
 {
   return *inoutarg += 1;
 }
 
 /**
- * annotation_object_inout2:
+ * regress_annotation_object_inout2:
  * @object: a #GObject
  * @inoutarg: (inout): This is an argument test
  *
@@ -266,14 +266,14 @@ annotation_object_inout (AnnotationObject *object, int *inoutarg)
  * Return value: an int
  */
 gint
-annotation_object_inout2 (AnnotationObject *object, int *inoutarg)
+regress_annotation_object_inout2 (RegressAnnotationObject *object, int *inoutarg)
 {
   return *inoutarg += 1;
 }
 
 
 /**
- * annotation_object_inout3:
+ * regress_annotation_object_inout3:
  * @object: a #GObject
  * @inoutarg: (inout) (allow-none): This is an argument test
  *
@@ -282,7 +282,7 @@ annotation_object_inout2 (AnnotationObject *object, int *inoutarg)
  * Return value: an int
  */
 gint
-annotation_object_inout3 (AnnotationObject *object, int *inoutarg)
+regress_annotation_object_inout3 (RegressAnnotationObject *object, int *inoutarg)
 {
   if (inoutarg)
     return *inoutarg + 1;
@@ -290,7 +290,7 @@ annotation_object_inout3 (AnnotationObject *object, int *inoutarg)
 }
 
 /**
- * annotation_object_calleeowns:
+ * regress_annotation_object_calleeowns:
  * @object: a #GObject
  * @toown: (out): a #GObject
  *
@@ -299,14 +299,14 @@ annotation_object_inout3 (AnnotationObject *object, int *inoutarg)
  * Return value: an int
  */
 gint
-annotation_object_calleeowns (AnnotationObject *object, GObject **toown)
+regress_annotation_object_calleeowns (RegressAnnotationObject *object, GObject **toown)
 {
   return 1;
 }
 
 
 /**
- * annotation_object_calleesowns:
+ * regress_annotation_object_calleesowns:
  * @object: a #GObject
  * @toown1: (out) (transfer full): a #GObject
  * @toown2: (out) (transfer none): a #GObject
@@ -316,16 +316,16 @@ annotation_object_calleeowns (AnnotationObject *object, GObject **toown)
  * Return value: an int
  */
 gint
-annotation_object_calleesowns (AnnotationObject *object,
-			       GObject **toown1,
-			       GObject **toown2)
+regress_annotation_object_calleesowns (RegressAnnotationObject *object,
+                                       GObject **toown1,
+                                       GObject **toown2)
 {
   return 1;
 }
 
 
 /**
- * annotation_object_get_strings:
+ * regress_annotation_object_get_strings:
  * @object: a #GObject
  *
  * This is a test for returning a list of strings, where
@@ -334,16 +334,16 @@ annotation_object_calleesowns (AnnotationObject *object,
  * Return value: (element-type utf8) (transfer full): list of strings
  */
 GList*
-annotation_object_get_strings (AnnotationObject *object)
+regress_annotation_object_get_strings (RegressAnnotationObject *object)
 {
   GList *list = NULL;
-  list = g_list_prepend (list, g_strdup ("annotation"));
+  list = g_list_prepend (list, g_strdup ("regress_annotation"));
   list = g_list_prepend (list, g_strdup ("bar"));
   return list;
 }
 
 /**
- * annotation_object_get_hash:
+ * regress_annotation_object_get_hash:
  * @object: a #GObject
  *
  * This is a test for returning a hash table mapping strings to
@@ -352,7 +352,7 @@ annotation_object_get_strings (AnnotationObject *object)
  * Return value: (element-type utf8 GObject) (transfer full): hash table
  */
 GHashTable*
-annotation_object_get_hash (AnnotationObject *object)
+regress_annotation_object_get_hash (RegressAnnotationObject *object)
 {
   GHashTable *hash = g_hash_table_new_full (g_str_hash, g_str_equal,
 					    g_free, g_object_unref);
@@ -362,27 +362,27 @@ annotation_object_get_hash (AnnotationObject *object)
 }
 
 /**
- * annotation_object_with_voidp:
+ * regress_annotation_object_with_voidp:
  * @data: Opaque pointer handle
  */
 void
-annotation_object_with_voidp (AnnotationObject *object, void *data)
+regress_annotation_object_with_voidp (RegressAnnotationObject *object, void *data)
 {
 
 }
 
 /**
- * annotation_object_get_objects:
+ * regress_annotation_object_get_objects:
  * @object: a #GObject
  *
  * This is a test for returning a list of objects.
  * The list itself should be freed, but not the internal objects,
  * intentionally similar example to gtk_container_get_children
  *
- * Return value: (element-type AnnotationObject) (transfer container): list of objects
+ * Return value: (element-type RegressAnnotationObject) (transfer container): list of objects
  */
 GSList*
-annotation_object_get_objects (AnnotationObject *object)
+regress_annotation_object_get_objects (RegressAnnotationObject *object)
 {
   GSList *list = NULL;
   list = g_slist_prepend (list, object);
@@ -390,7 +390,7 @@ annotation_object_get_objects (AnnotationObject *object)
 }
 
 /**
- * annotation_object_create_object:
+ * regress_annotation_object_create_object:
  * @object: a #GObject
  *
  * Test returning a caller-owned object
@@ -398,39 +398,39 @@ annotation_object_get_objects (AnnotationObject *object)
  * Return value: (transfer full): The object
  **/
 GObject*
-annotation_object_create_object (AnnotationObject *object)
+regress_annotation_object_create_object (RegressAnnotationObject *object)
 {
-	return g_object_ref (object);
+  return g_object_ref (object);
 }
 
 /**
- * annotation_object_use_buffer:
+ * regress_annotation_object_use_buffer:
  * @object: a #GObject
  *
  **/
 void
-annotation_object_use_buffer   (AnnotationObject *object,
-				guchar           *bytes)
+regress_annotation_object_use_buffer   (RegressAnnotationObject *object,
+                                        guchar           *bytes)
 {
 
 }
 
 /**
- * annotation_object_compute_sum:
+ * regress_annotation_object_compute_sum:
  * @object: a #GObject
  * @nums: (array): Sequence of numbers
  *
  * Test taking a zero-terminated array
  **/
 void
-annotation_object_compute_sum  (AnnotationObject *object,
-				int              *nums)
+regress_annotation_object_compute_sum  (RegressAnnotationObject *object,
+                                        int              *nums)
 {
 
 }
 
 /**
- * annotation_object_compute_sum_n:
+ * regress_annotation_object_compute_sum_n:
  * @object: a #GObject
  * @nums: (array length=n_nums zero-terminated=0): Sequence of
  *   numbers that are zero-terminated
@@ -439,16 +439,16 @@ annotation_object_compute_sum  (AnnotationObject *object,
  * Test taking an array with length parameter
  **/
 void
-annotation_object_compute_sum_n(AnnotationObject *object,
-				int              *nums,
-				int               n_nums)
+regress_annotation_object_compute_sum_n(RegressAnnotationObject *object,
+                                        int              *nums,
+                                        int               n_nums)
 {
 
 }
 
 /**
- * annotation_object_compute_sum_nz:
- * @object: a #AnnotationObject
+ * regress_annotation_object_compute_sum_nz:
+ * @object: a #RegressAnnotationObject
  * @nums: (array length=n_nums zero-terminated=1): Sequence of numbers that
  * are zero-terminated
  * @n_nums: Length of number array
@@ -456,32 +456,32 @@ annotation_object_compute_sum_n(AnnotationObject *object,
  * Test taking a zero-terminated array with length parameter
  **/
 void
-annotation_object_compute_sum_nz(AnnotationObject *object,
-                                 int             *nums,
-                                 int              n_nums)
+regress_annotation_object_compute_sum_nz(RegressAnnotationObject *object,
+                                         int             *nums,
+                                         int              n_nums)
 {
 
 }
 
 /**
- * annotation_object_parse_args:
- * @object: a #AnnotationObject
+ * regress_annotation_object_parse_args:
+ * @object: a #RegressAnnotationObject
  * @argc: (inout): Length of the argument vector
  * @argv: (inout) (array length=argc zero-terminated=1): Argument vector
  *
  * Test taking a zero-terminated array with length parameter
  **/
 void
-annotation_object_parse_args(AnnotationObject *object,
-                             int              *argc,
-                             char           ***argv)
+regress_annotation_object_parse_args(RegressAnnotationObject *object,
+                                     int              *argc,
+                                     char           ***argv)
 {
 
 }
 
 /**
- * annotation_object_string_out:
- * @object: a #AnnotationObject
+ * regress_annotation_object_string_out:
+ * @object: a #RegressAnnotationObject
  * @str_out: (out) (transfer full): string return value
  *
  * Test returning a string as an out parameter
@@ -489,63 +489,63 @@ annotation_object_parse_args(AnnotationObject *object,
  * Returns: some boolean
  **/
 gboolean
-annotation_object_string_out(AnnotationObject *object,
-                             char            **str_out)
+regress_annotation_object_string_out(RegressAnnotationObject *object,
+                                     char            **str_out)
 {
   return FALSE;
 }
 
 /**
- * annotation_object_foreach:
- * @object: a #AnnotationObject
+ * regress_annotation_object_foreach:
+ * @object: a #RegressAnnotationObject
  * @func: (scope call): Callback to invoke
  * @user_data: Callback user data
  *
  * Test taking a call-scoped callback
  **/
 void
-annotation_object_foreach (AnnotationObject *object,
-                           AnnotationForeachFunc func,
-                           gpointer user_data)
+regress_annotation_object_foreach (RegressAnnotationObject *object,
+                                   RegressAnnotationForeachFunc func,
+                                   gpointer user_data)
 {
-  
+
 }
 
 /**
- * annotation_object_set_data:
- * @object: a #AnnotationObject
+ * regress_annotation_object_set_data:
+ * @object: a #RegressAnnotationObject
  * @data: (array length=length): The data
  * @length: Length of the data
  *
  * Test taking a guchar * with a length.
  **/
 void
-annotation_object_set_data (AnnotationObject *object,
-                            const guchar *data,
-                            gsize length)
+regress_annotation_object_set_data (RegressAnnotationObject *object,
+                                    const guchar *data,
+                                    gsize length)
 {
-  
+
 }
 
 /**
- * annotation_object_set_data2:
- * @object: a #AnnotationObject
+ * regress_annotation_object_set_data2:
+ * @object: a #RegressAnnotationObject
  * @data: (array length=length) (element-type gint8): The data
  * @length: Length of the data
  *
  * Test taking a gchar * with a length.
  **/
 void
-annotation_object_set_data2 (AnnotationObject *object,
-                             const gchar *data,
-                             gsize length)
+regress_annotation_object_set_data2 (RegressAnnotationObject *object,
+                                     const gchar *data,
+                                     gsize length)
 {
-  
+
 }
 
 /**
- * annotation_object_set_data3:
- * @object: a #AnnotationObject
+ * regress_annotation_object_set_data3:
+ * @object: a #RegressAnnotationObject
  * @data: (array length=length) (element-type guint8): The data
  * @length: Length of the data
  *
@@ -553,233 +553,233 @@ annotation_object_set_data2 (AnnotationObject *object,
  * type.
  **/
 void
-annotation_object_set_data3 (AnnotationObject *object,
-                             gpointer data,
-                             gsize length)
+regress_annotation_object_set_data3 (RegressAnnotationObject *object,
+                                     gpointer data,
+                                     gsize length)
 {
-  
+
 }
 
 /**
- * annotation_object_allow_none:
+ * regress_annotation_object_allow_none:
  * @object: a #GObject
  * @somearg: (allow-none):
  *
  * Returns: (transfer none): %NULL always
  **/
 GObject*
-annotation_object_allow_none (AnnotationObject *object, const gchar *somearg)
+regress_annotation_object_allow_none (RegressAnnotationObject *object, const gchar *somearg)
 {
   return NULL;
 }
 
 /**
- * annotation_object_notrans:
+ * regress_annotation_object_notrans:
  * @object: a #GObject
  *
  * Returns: (transfer none): An object, not referenced
  **/
 
 GObject*
-annotation_object_notrans (AnnotationObject *object)
+regress_annotation_object_notrans (RegressAnnotationObject *object)
 {
   return NULL;
 }
 
 /**
- * annotation_object_do_not_use:
+ * regress_annotation_object_do_not_use:
  * @object: a #GObject
  *
  * Returns: (transfer none): %NULL always
- * Deprecated: 0.12: Use annotation_object_create_object() instead.
+ * Deprecated: 0.12: Use regress_annotation_object_create_object() instead.
  **/
 GObject*
-annotation_object_do_not_use (AnnotationObject *object)
+regress_annotation_object_do_not_use (RegressAnnotationObject *object)
 {
   return NULL;
 }
 
 /**
- * annotation_object_watch: (skip)
- * @object: A #AnnotationObject
+ * regress_annotation_object_watch: (skip)
+ * @object: A #RegressAnnotationObject
  * @func: The callback
  * @user_data: The callback data
  *
  * This is here just for the sake of being overriden by its
- * annotation_object_watch_full().
+ * regress_annotation_object_watch_full().
  */
 void
-annotation_object_watch (AnnotationObject *object,
-                         AnnotationForeachFunc func,
-                         gpointer user_data)
+regress_annotation_object_watch (RegressAnnotationObject *object,
+                                 RegressAnnotationForeachFunc func,
+                                 gpointer user_data)
 {
 }
 
 /**
- * annotation_object_watch_full:
- * @object: A #AnnotationObject
+ * regress_annotation_object_watch_full:
+ * @object: A #RegressAnnotationObject
  * @func: The callback
  * @user_data: The callback data
  * @destroy: Destroy notification
  *
- * Test overriding via the "Rename To" annotation.
+ * Test overriding via the "Rename To" regress_annotation.
  *
- * Rename to: annotation_object_watch
+ * Rename to: regress_annotation_object_watch
  */
 void
-annotation_object_watch_full (AnnotationObject *object,
-                              AnnotationForeachFunc func,
-                              gpointer user_data,
-                              GDestroyNotify destroy)
+regress_annotation_object_watch_full (RegressAnnotationObject *object,
+                                      RegressAnnotationForeachFunc func,
+                                      gpointer user_data,
+                                      GDestroyNotify destroy)
 {
 }
 
 /**
- * annotation_object_hidden_self:
- * @object: (type AnnotationObject): A #AnnotationObject
+ * regress_annotation_object_hidden_self:
+ * @object: (type RegressAnnotationObject): A #RegressAnnotationObject
  **/
 void
-annotation_object_hidden_self (gpointer object)
+regress_annotation_object_hidden_self (gpointer object)
 {
 }
 
 /**
- * annotation_init:
- * @argc: (inout): The number of args. 
+ * regress_annotation_init:
+ * @argc: (inout): The number of args.
  * @argv: (inout) (array length=argc): The arguments.
  **/
 void
-annotation_init (int *argc, char ***argv)
+regress_annotation_init (int *argc, char ***argv)
 {
 
 }
 
 /**
- * annotation_return_array:
+ * regress_annotation_return_array:
  * @length: (out): Number of return values
  *
  * Return value: (transfer full) (array length=length): The return value
  **/
 char **
-annotation_return_array (int *length)
+regress_annotation_return_array (int *length)
 {
   return NULL;
 }
 
 /**
- * annotation_string_zero_terminated:
+ * regress_annotation_string_zero_terminated:
  *
  * Return value: (transfer full) (array zero-terminated=1): The return value
  **/
 char **
-annotation_string_zero_terminated (void)
+regress_annotation_string_zero_terminated (void)
 {
   return NULL;
 }
 
 /**
- * annotation_string_zero_terminated_out:
+ * regress_annotation_string_zero_terminated_out:
  * @out: (array zero-terminated=1) (inout):
  **/
 void
-annotation_string_zero_terminated_out (char ***out)
+regress_annotation_string_zero_terminated_out (char ***out)
 {
 }
 
 /**
- * annotation_versioned:
+ * regress_annotation_versioned:
  *
  * Since: 0.6
  **/
 void
-annotation_versioned (void)
+regress_annotation_versioned (void)
 {
 }
 
 /**
- * annotation_string_array_length:
+ * regress_annotation_string_array_length:
  * @n_properties:
  * @properties: (array length=n_properties) (element-type utf8):
  */
 void
-annotation_string_array_length (guint n_properties, const gchar * const properties[])
+regress_annotation_string_array_length (guint n_properties, const gchar * const properties[])
 {
 }
 
 /**
- * annotation_object_extra_annos:
+ * regress_annotation_object_extra_annos:
  *
  * Attributes: (org.foobar testvalue)
  */
 void
-annotation_object_extra_annos (AnnotationObject *object)
+regress_annotation_object_extra_annos (RegressAnnotationObject *object)
 {
 }
 
 /**
- * annotation_custom_destroy:
+ * regress_annotation_custom_destroy:
  * @callback: (destroy destroy) (closure data): Destroy notification
  *
  * Test messing up the heuristic of closure/destroy-notification
- * detection, and fixing it via annotations.
+ * detection, and fixing it via regress_annotations.
  */
 void
-annotation_custom_destroy (AnnotationCallback callback,
-                           AnnotationNotifyFunc destroy,
-                           gpointer data)
+regress_annotation_custom_destroy (RegressAnnotationCallback callback,
+                                   RegressAnnotationNotifyFunc destroy,
+                                   gpointer data)
 {
 }
 
 /**
- * annotation_get_source_file:
+ * regress_annotation_get_source_file:
  *
  * Return value: (type filename) (transfer full): Source file
  */
 char *
-annotation_get_source_file (void)
+regress_annotation_get_source_file (void)
 {
   return NULL;
 }
 
 /**
- * annotation_set_source_file:
+ * regress_annotation_set_source_file:
  * @fname: (type filename): Source file
  *
  */
 void
-annotation_set_source_file (const char *fname)
+regress_annotation_set_source_file (const char *fname)
 {
 }
 
 /**
- * annotation_ptr_array:
- * @array: (element-type GLib.Value): the array
+ * regress_annotation_ptr_array:
+ * @array: (element-type GObject.Value): the array
  */
 void
-annotation_ptr_array (GPtrArray *array)
+regress_annotation_ptr_array (GPtrArray *array)
 {
 }
 
 /**
- * annotation_attribute_func:
- * @object: A #AnnotationObject.
- * @data: (attribute some.annotation value) (attribute another.annotation blahvalue): Some data.
+ * regress_annotation_attribute_func:
+ * @object: A #RegressAnnotationObject.
+ * @data: (attribute some.regress_annotation value) (attribute another.regress_annotation blahvalue): Some data.
  *
- * Returns: (attribute some.other.annotation value2) (attribute yet.another.annotation another_value): The return value.
+ * Returns: (attribute some.other.regress_annotation value2) (attribute yet.another.regress_annotation another_value): The return value.
  */
 gint
-annotation_attribute_func (AnnotationObject *object,
-                           const gchar      *data)
+regress_annotation_attribute_func (RegressAnnotationObject *object,
+                                   const gchar      *data)
 {
   return 42;
 }
 
 /**
- * annotation_invalid_annotation:
+ * regress_annotation_invalid_regress_annotation:
  * @foo: some text (e.g. example) or else
  */
 void
-annotation_invalid_annotation (int foo)
+regress_annotation_invalid_regress_annotation (int foo)
 {
 
 }
@@ -789,47 +789,47 @@ char backslash_parsing_tester_2 = '\\';
 
 
 /**
- * annotation_test_parsing_bug630862:
+ * regress_annotation_test_parsing_bug630862:
  *
  * See https://bugzilla.gnome.org/show_bug.cgi?id=630862
  *
  * Returns: (transfer none): An object, note the colon:in here
  */
 GObject  *
-annotation_test_parsing_bug630862 (void)
+regress_annotation_test_parsing_bug630862 (void)
 {
   return NULL;
 }
 
 
-/** 
- * annotation_space_after_comment_bug631690:
+/**
+ * regress_annotation_space_after_comment_bug631690:
  *
  * Explicitly test having a space after the ** here.
  */
 void
-annotation_space_after_comment_bug631690 (void)
+regress_annotation_space_after_comment_bug631690 (void)
 {
 }
 
 /**
- * annotation_return_filename:
+ * regress_annotation_return_filename:
  *
  * Returns: (type filename): An annotated filename
  */
 gchar*
-annotation_return_filename (void)
+regress_annotation_return_filename (void)
 {
   return "a utf-8 filename";
 }
 
 /**
- * annotation_transfer_floating:
+ * regress_annotation_transfer_floating:
  *
  * Returns: (transfer floating): A floating object
  */
 GObject *
-annotation_transfer_floating(void)
+regress_annotation_transfer_floating(void)
 {
   return NULL;
 }
